@@ -1,13 +1,15 @@
 #ifndef RZ_CONFIGURE_H
 #define RZ_CONFIGURE_H
 
-#include "rz_version.h"
+#include "rz_build_version.h"
 
 // clang-format off
 #define RZ_CHECKS_LEVEL             2
 #define DEBUGGER                    1
 #define HAVE_THREADS                1
 #define HAVE_PTHREAD                1
+#define HAVE_LZMA                   1
+#define HAVE_ZLIB                   1
 #define HAVE_DECL_ADDR_NO_RANDOMIZE 1
 #define HAVE_DECL_PROCCTL_ASLR_CTL  0
 #define HAVE_ARC4RANDOM_UNIFORM     1
@@ -33,11 +35,10 @@
 #define HAVE_LIB_XXHASH             1
 #define USE_LIB_XXHASH              1
 #define HAVE_LIB_SSL                1
-#define HAVE_LIBUV                  1
 #define HAVE_PTRACE                 1
 #define USE_PTRACE_WRAP             1
 #define HAVE_FORK                   1
-#define HAVE_STRLCPY                0
+#define HAVE_STRLCPY                1
 #define HAVE_STRNLEN                1
 #define WANT_DYLINK                 1
 #define WITH_GPL                    1
@@ -47,28 +48,34 @@
 #define WITH_SWIFT_DEMANGLER        1
 #define HAVE_COPYFILE               0
 #define HAVE_COPY_FILE_RANGE        1
+#define HAVE_BACKTRACE              1
+#define HAVE___BUILTIN_BSWAP16      1
+#define HAVE___BUILTIN_BSWAP32      1
+#define HAVE___BUILTIN_BSWAP64      1
+#define HAVE_POSIX_MEMALIGN         1
+#define HAVE__ALIGNED_MALLOC        0
 
 #define HAVE_HEADER_LINUX_ASHMEM_H  0
 #define HAVE_HEADER_SYS_SHM_H       1
 #define HAVE_HEADER_SYS_IPC_H       1
 #define HAVE_HEADER_SYS_MMAN_H      1
+#define HAVE_HEADER_INTTYPES_H      1
 
 #define RZ_IS_PORTABLE 0
+
+#define RZ_BINDIR_DEPTH 1
 // clang-format on
 
-#define RZ_PREFIX  "/usr"
-#define RZ_BINDIR  "bin"
-#define RZ_LIBDIR  "lib"
-#define RZ_INCDIR  "include/librz"
-#define RZ_DATDIR  "share"
-#define RZ_WWWROOT "share/rizin/www"
-
-#define RZ_BINDIR_DEPTH  1
+#define RZ_PREFIX "/usr"
+#define RZ_BINDIR "bin"
+#define RZ_LIBDIR "lib"
+#define RZ_INCDIR "include/librz"
+#define RZ_DATDIR "share"
 
+#define RZ_WWWROOT  "share/rizin/www"
 #define RZ_PLUGINS  "lib/rizin/plugins"
 #define RZ_DATADIR  "share/rizin"
 #define RZ_SDB      "share/rizin"
-#define RZ_ZIGNS    "share/rizin/zigns"
 #define RZ_SIGDB    "share/rizin/sigdb"
 #define RZ_THEMES   "share/rizin/cons"
 #define RZ_FORTUNES "share/rizin/fortunes"
@@ -91,14 +98,18 @@
 #define RZ_HOME_CACHEDIR  RZ_JOIN_2_PATHS(".cache", "rizin")
 
 #define RZ_HOME_HISTORY RZ_JOIN_2_PATHS(RZ_HOME_CACHEDIR, "history")
-// NOTE: Temporarly added only for compatibility reasons given that the plugin
-// directory has changed. For one release we are going to support also old paths
-// to give distros, plugin maintainers, etc. a bit more time to adapt
-#define RZ_HOME_OLD_PLUGINS RZ_JOIN_3_PATHS("share", "rizin", "plugins")
 
 #define RZ_HOME_CONFIG_RC     RZ_JOIN_2_PATHS(RZ_HOME_CONFIGDIR, "rizinrc")
 #define RZ_HOME_CONFIG_RC_DIR RZ_JOIN_2_PATHS(RZ_HOME_CONFIGDIR, "rizinrc.d")
 #define RZ_GLOBAL_RC          RZ_JOIN_2_PATHS(RZ_DATADIR, "rizinrc")
 #define RZ_HOME_RC            ".rizinrc"
 
+// This is an optional extra prefix used to load plugins, sdb files, sdb files,
+// etc. It can be outside the default prefix. Used e.g. by Homebrew to load
+// plugins from the general /opt/homebrew prefix instead of the version specific
+// prefix e.g. /opt/homebrew/Cellar/rizin/0.x.y/
+// clang-format off
+#define RZ_EXTRA_PREFIX 0
+// clang-format on
+
 #endif
